@@ -10,7 +10,7 @@ http://stackoverflow.com/questions/11505708/lining-up-labelled-dendrograms-with-
 import scipy
 import pylab as pl
 import scipy.cluster.hierarchy as sch
-import survey2.util.distances as distances
+import pysurvey.util.distances as distances
 import numpy as np
 
 from numpy import arange, log10, nan, array
@@ -496,4 +496,4 @@ if __name__ == '__main__':
 #    test_plot_heatmap()
                 
                 
-    
\ No newline at end of file
+    
