@@ -301,7 +301,7 @@ def compute_qvals(G, method='direct'):
     '''
     Compute q-values corresponding to p-values obtained using specified 'method'.
     '''
-    from survey2.util.R_utilities import R_qvalues
+    from pysurvey.util.R_utilities import R_qvalues
     p_vals = G.p_vals[method]
     n      = p_vals.matrix.shape[0]
     
@@ -1123,4 +1123,4 @@ if __name__ == '__main__':
  
 
    
-       
\ No newline at end of file
+       
